@@ -14,6 +14,11 @@ class APIErrorCode(str, Enum):
     CLIENT_CREATE_UNKNOWN_TENANT = "CLIENT_CREATE_UNKNOWN_TENANT"
     CLIENT_HTTPS_REQUIRED_ON_REDIRECT_URIS = "CLIENT_HTTPS_REQUIRED_ON_REDIRECT_URIS"
 
+    USER_FIELD_SLUG_ALREADY_EXISTS = "USER_FIELD_SLUG_ALREADY_EXISTS"
+
     USER_CREATE_UNKNOWN_TENANT = "USER_CREATE_UNKNOWN_TENANT"
     USER_CREATE_ALREADY_EXISTS = "USER_CREATE_ALREADY_EXISTS"
     USER_CREATE_INVALID_PASSWORD = "USER_CREATE_INVALID_PASSWORD"
+
+    USER_UPDATE_INVALID_PASSWORD = "USER_UPDATE_INVALID_PASSWORD"
+    USER_UPDATE_EMAIL_ALREADY_EXISTS = "USER_UPDATE_EMAIL_ALREADY_EXISTS"
